==> kwin-5.22.4.tar.xz: kwin-5.22.4/src/plugins/kdecorations/aurorae/src/aurorae.knsrc.cmake <==
[KNewStuff3]
Name=Aurorae Window Decorations
Name[az]=Aurorae Pəncərə Dekorasiyası
Name[ca]=Decoracions de finestra Aurorae
Name[ca@valencia]=Decoracions de finestra Aurorae
Name[cs]=Dekorace oken Aurorae
Name[da]=Aurorae vinduesdekorationer
Name[de]=Aurorae-Fensterdekoration
Name[el]=Διακοσμήσεις παραθύρου Aurorae
Name[en_GB]=Aurorae Window Decorations
Name[es]=Decoraciones de las ventanas Aurorae
Name[et]=Aurorae aknadekoratsioonid
Name[eu]=Aurorae leihoentzako apaingarriak
Name[fi]=Aurorae-ikkunakehykset
Name[fr]=Décorations de fenêtres Aurorae
Name[gl]=Decoracións de xanela de Aurorae
Name[hu]=Aurorae ablakdekorációk
Name[ia]=Decorationes de fenestra Aurorae
Name[id]=Dekorasi Window Aurorae
Name[it]=Decorazioni delle finestre Aurorae
Name[ko]=Aurorae 창 장식
Name[lt]=Aurorae langų dekoracijos
Name[nl]=Aurorea-vensterdecoraties
Name[nn]=Aurorae-vindaugsdekorasjonar
Name[pl]=Ozdoby okienne Aurorae
Name[pt]=Decorações das Janelas do Aurorae
Name[pt_BR]=Decorações da janela Aurorae
Name[ro]=Decorații de fereastră Aurorae
Name[ru]=Оформления окон Aurorae для KWin
Name[sk]=Dekorácie okien Aurorae
Name[sl]=Okraski oken Aurorae
Name[sr]=Декорације прозора за Ауроре
Name[sr@ijekavian]=Декорације прозора за Ауроре
Name[sr@ijekavianlatin]=Dekoracije prozora za Aurore
Name[sr@latin]=Dekoracije prozora za Aurore
Name[sv]=Aurora-fönsterdekorationer
Name[tr]=Aurorae Pencere Dekorasyonları
Name[uk]=Обрамлення вікон Aurorae
Name[x-test]=xxAurorae Window Decorationsxx
Name[zh_CN]=Aurorae 极光窗口装饰
Name[zh_TW]=Aurorae 視窗裝飾

ProvidersUrl=https://download.kde.org/ocs/providers.xml
Categories=Window Decoration Aurorae
Uncompress=archive
TargetDir=aurorae/themes
AdoptionCommand=@KDE_INSTALL_LIBEXECDIR@/kwin-applywindowdecoration %f

==> kwin-6.3.1.tar.xz: kwin-6.3.1/src/plugins/kdecorations/aurorae/src/aurorae.knsrc.cmake <==
[KNewStuff3]
Name=Aurorae Window Decorations
Name[az]=Aurorae Pəncərə Dekorasiyası
Name[ca]=Decoracions de finestra Aurorae
Name[ca@valencia]=Decoracions de finestra Aurorae
Name[cs]=Dekorace oken Aurorae
Name[da]=Aurorae vinduesdekorationer
Name[de]=Aurorae-Fensterdekoration
Name[el]=Διακοσμήσεις παραθύρου Aurorae
Name[en_GB]=Aurorae Window Decorations
Name[es]=Decoraciones de las ventanas Aurorae
Name[et]=Aurorae aknadekoratsioonid
Name[eu]=Aurorae leihoentzako apaingarriak
Name[fi]=Aurorae-ikkunakehykset
Name[fr]=Décorations de fenêtres Aurorae
Name[gl]=Decoracións de xanela de Aurorae
Name[hu]=Aurorae ablakdekorációk
Name[ia]=Decorationes de fenestra Aurorae
Name[id]=Dekorasi Window Aurorae
Name[it]=Decorazioni delle finestre Aurorae
Name[ko]=Aurorae 창 장식
Name[lt]=Aurorae langų dekoracijos
Name[nl]=Aurorea-vensterdecoraties
Name[nn]=Aurorae-vindaugsdekorasjonar
Name[pl]=Ozdoby okienne Aurorae
Name[pt]=Decorações das Janelas do Aurorae
Name[pt_BR]=Decorações da janela Aurorae
Name[ro]=Decorații de fereastră Aurorae
Name[ru]=Оформления окон Aurorae для KWin
Name[sk]=Dekorácie okien Aurorae
Name[sl]=Okraski oken Aurorae
Name[sr]=Декорације прозора за Ауроре
Name[sr@ijekavian]=Декорације прозора за Ауроре
Name[sr@ijekavianlatin]=Dekoracije prozora za Aurore
Name[sr@latin]=Dekoracije prozora za Aurore
Name[sv]=Aurora-fönsterdekorationer
Name[tr]=Aurorae Pencere Dekorasyonları
Name[uk]=Обрамлення вікон Aurorae
Name[x-test]=xxAurorae Window Decorationsxx
Name[zh_CN]=Aurorae 极光窗口装饰
Name[zh_TW]=Aurorae 視窗裝飾

ProvidersUrl=https://autoconfig.kde.org/ocs/providers.xml
ContentWarning=Executables
Categories=Window Decoration Aurorae
Uncompress=archive
TargetDir=aurorae/themes
AdoptionCommand=@KDE_INSTALL_LIBEXECDIR@/kwin-applywindowdecoration %f
